@@ -2,7 +2,6 @@
 #' 
 #' This is an environment with some methods. Every class defined by \code{defineClass} will inherit from aoos. Summary will show a list of public and private members with approximated memory usage.
 #' 
-#' @import methods
 #' @exportClass aoos
 #' @rdname aoos
 setClass("aoos", contains = c("environment", "VIRTUAL"))
@@ -106,4 +105,8 @@ envSize <- function (env) {
   
   out[order(out$Name, out$Type), ]
     
-}
\ No newline at end of file
+}
+
+#' @rdname aoos
+#' @export
+setMethod("as.environment", "aoos", function(x) parent.env(x))
\ No newline at end of file
