@@ -3,9 +3,9 @@ test_that("Summary", {
   suppressWarnings({
     test <- defineClass("test", {
       x <- publicValue(1)
-      y <- NULL
+      .y <- NULL
       doSomething <- publicFunction(function() {
-        y <<- y + 1
+        .y <<- .y + 1
         invisible(self)
       })
     })
@@ -14,8 +14,8 @@ test_that("Summary", {
   instance <- test()
   df <- summary(instance)
   expect_is(df, "data.frame")
-  expect_equal(nrow(df), 6)
-  expect_equal(rownames(df), c("doSomething", "self", "x", "x.validity", "x.x", "y"))
+  expect_equal(nrow(df), 7)
+  expect_equal(sort(df$Name), 
+               sort(c("doSomething", "self", ".self", "x", "x.validity", "x.x", ".y")))
   
-  removeClass("test")
 })
\ No newline at end of file
